@@ -92,6 +92,8 @@ class Model(django.db.models.base.Model):
         """
         Saves the current instance.
         """
+        signals.pre_save.send(sender=self.__class__, instance=self)
+        
         using = using or router.db_for_write(self.__class__, instance=self)
         connection = connections[using]
         if not self.dn:
@@ -104,10 +106,9 @@ class Model(django.db.models.base.Model):
                 if not field.db_column:
                     continue
                 value = getattr(self, field.name)
+                value = field.get_db_prep_save(value, connection=connection)
                 if value:
-                    entry.append((field.db_column,
-                                  field.get_db_prep_save(
-                                      value, connection=connection)))
+                    entry.append((field.db_column, value))
 
             logger.debug("Creating new LDAP entry %s" % new_dn)
             connection.add_s(new_dn, entry)
@@ -126,11 +127,11 @@ class Model(django.db.models.base.Model):
                 old_value = getattr(orig, field.name, None)
                 new_value = getattr(self, field.name, None)
                 if old_value != new_value:
+                    new_value = field.get_db_prep_save(new_value, 
+                                        connection=connection)
                     if new_value:
-                        modlist.append(
-                            (ldap.MOD_REPLACE, field.db_column,
-                             field.get_db_prep_save(new_value,
-                                                    connection=connection)))
+                        modlist.append((ldap.MOD_REPLACE, field.db_column, 
+                                        new_value))
                     elif old_value:
                         modlist.append((ldap.MOD_DELETE, field.db_column,
                                         None))
@@ -162,6 +163,8 @@ class Model(django.db.models.base.Model):
         """
         class Meta:
             proxy = True
+            verbose_name = base_class._meta.verbose_name
+            verbose_name_plural = base_class._meta.verbose_name_plural
         import re
         suffix = re.sub('[=,]', '_', base_dn)
         name = "%s_%s" % (base_class.__name__, str(suffix))
